.. _spkg_arithmat:

arithmat: Sage implementation of arithmetic matroids and toric arrangements
===========================================================================

Description
-----------

Sage implementation of arithmetic matroids and toric arrangements

License
-------

GPLv3

Upstream Contact
----------------

https://pypi.org/project/arithmat/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)
- :ref:`spkg_sagemath_combinat`
- :ref:`spkg_sagemath_graphs`
- :ref:`spkg_sagemath_modules`
- :ref:`spkg_sagemath_repl`

Version Information
-------------------

requirements.txt::

    arithmat @ git+https://github.com/passagemath/passagemath-pkg-arithmat

Equivalent System Packages
--------------------------

(none known)
